@@ -20,11 +20,12 @@ def execute(
     numcores: int = typer.Option(multiprocessing.cpu_count(), '--numcores','-n', help='The number of cores will be used.'),
     pvalue: float = typer.Option(0.1,  '--pvalue','-p', help='P-value cutoff for stripe.'),
     mask: str = typer.Option('0', "--mask", help='Column coordinates to be masked. e.g., chr9:12345678-12345789'),
-    slow: bool= typer.Option(False,"-s", help='Use if system memory is low.')
+    slow: bool= typer.Option(False,"-s", help='Use if system memory is low.'),
+    bfilter: int=typer.Option(3,"--bfilter",'-b',help="Mean filter size. should be an odd number")
 ):
     """Finds stripe coordinates from 3D genomic data
     """
-    stripenn.compute(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue, mask, slow)
+    stripenn.compute(cool, out, norm, chrom, canny, minL, maxW, maxpixel, numcores, pvalue, mask, slow, bfilter)
 
 @app.command('seeimage')
 def seeimag(
