@@ -16,7 +16,7 @@ from joblib import Parallel, delayed
 from tqdm import tqdm
 
 class getStripe:
-    def __init__(self, unbalLib, resol, minH, maxW, canny, all_chromnames, chromnames, all_chromsizes, chromsizes, core):
+    def __init__(self, unbalLib, resol, minH, maxW, canny, all_chromnames, chromnames, all_chromsizes, chromsizes, core, bfilter):
         self.unbalLib = unbalLib
         self.resol = resol
         self.minH = minH
@@ -27,6 +27,7 @@ class getStripe:
         self.chromnames = chromnames
         self.chromsizes = chromsizes
         self.core = core
+        self.bfilter = bfilter
         self.chromnames2sizes={}
         for i in range(len(self.all_chromnames)):
             self.chromnames2sizes[self.all_chromnames[i]] = self.all_chromsizes[i]
@@ -554,8 +555,11 @@ class getStripe:
                     leftmost = 1
                 if rightmost > chrLen:
                     rightmost = chrLen
-                cd1 = chr + ":" + str(leftmost) + "-" + str(rightmost)
-                cd2 = chr + ":" + str(pos3) + "-" + str(pos4)
+                cd1 = chr + ":" + str(int(float(leftmost))) + "-" + str(int(float(rightmost)))
+                cd2 = chr + ":" + str(int(float(pos3))) + "-" + str(int(float(pos4)))
+		print('abcdefg')
+		print(cd1)
+		print(cd2)
                 mat = self.unbalLib.fetch(cd2, cd1)
                 mat_center = mat[:, background_size:(-1*background_size)]
                 mat_left = mat[:, :background_size]
@@ -771,7 +775,7 @@ class getStripe:
             is_mask = False
             if mask!='0':
                 is_mask = ( mask_chr == c )
-            print(c)
+
             idx = np.where(df['chr'] == c)[0].tolist()
             chrom_idx = self.chromnames.index(c)
             chrom_bin_size = np.ceil(self.chromsizes[chrom_idx] / self.resol)
@@ -901,7 +905,8 @@ class getStripe:
                     adj = ImageProcessing.imBrightness3D(img, In=([0.0, 0.0, 0.0], [1.0, b, b]),
                                                          Out=([0.0, 0.0, 0.0], [1.0, 1.0, 1.0]))
                     # plt.subplot(111), plt.imshow(adj), plt.title('Brightened'), plt.show()
-                    kernel = np.ones((3, 3)) / 9
+                    bfilt = int(self.bfilter) # modified 21 10 23
+                    kernel = np.ones((bfilt, bfilt)) / (bfilt*bfilt) # modified 21 10 23
                     blur = cv.filter2D(adj, -1, kernel)
                     blur = np.clip(blur, a_min=0, a_max=1)
                     # plt.subplot(111), plt.imshow(blur), plt.title('Blurry'), plt.show()
