@@ -32,7 +32,7 @@ def getScore(cool, coordinates,norm,numcores,out,mask='0'):
         norm = False
 
     all_chromnames = Lib.chromnames
-    all_chromnames = [x for x in all_chromnames if x != "Y"]
+    all_chromnames = [str(x) for x in all_chromnames if x != "Y"]
     #all_chromsizes = Lib.chromsizes
     all_chromsizes = [Lib.chromsizes[i] for i in range(len(Lib.chromsizes)) if Lib.chromnames[i]!="Y"]
     all_chromsizes = np.array(all_chromsizes)
